package logjson

import (
	"bytes"
	"sync"
)

type BytesBufferPool interface {
	Get() *bytes.Buffer
	Put(buffer *bytes.Buffer)
}

func newBytesBufferPool(initialSize, maximumSize int) *bytesBufferPool {
	return &bytesBufferPool{
		pool: sync.Pool{
			New: func() any {
				return bytes.NewBuffer(make([]byte, 0, initialSize))
			},
		},
		maximumSize: maximumSize,
	}
}

type bytesBufferPool struct {
	pool        sync.Pool
	maximumSize int
}

func (pool *bytesBufferPool) Get() *bytes.Buffer {
	return pool.pool.Get().(*bytes.Buffer)
}

func (pool *bytesBufferPool) Put(buf *bytes.Buffer) {
	if buf.Cap() > pool.maximumSize {
		return
	}
	pool.pool.Put(buf)
}
